from setuptools import setup
 
setup(
     name='lara_mg3',    # This is the name of your PyPI-package.
     version='0.1',                          # Update the version number for new releases
     scripts=['hi']                  # The name of your scipt, and also the command you'll be using for calling it
 )
